/*******************************************************************************
 * Copyright (C) 2017 Philipp Spohr
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package de.hhu.ba.yoshikoWrapper.core;

import org.cytoscape.application.events.SetCurrentNetworkEvent;
import org.cytoscape.application.events.SetCurrentNetworkListener;
import org.cytoscape.model.events.AddedEdgesEvent;
import org.cytoscape.model.events.AddedEdgesListener;
import org.cytoscape.model.events.ColumnCreatedEvent;
import org.cytoscape.model.events.ColumnCreatedListener;
import org.cytoscape.model.events.ColumnDeletedEvent;
import org.cytoscape.model.events.ColumnDeletedListener;
import org.cytoscape.model.events.RemovedEdgesEvent;
import org.cytoscape.model.events.RemovedEdgesListener;
import org.cytoscape.session.events.SessionLoadedEvent;
import org.cytoscape.session.events.SessionLoadedListener;

import de.hhu.ba.yoshikoWrapper.swing.components.ColumnMapper;

public class NetChangeListener 
implements //everything
AddedEdgesListener,
RemovedEdgesListener,
ColumnCreatedListener,
ColumnDeletedListener,
SessionLoadedListener,
SetCurrentNetworkListener
{
	private ColumnMapper columnMapper;
	
	public NetChangeListener(ColumnMapper columnMapper) {
		this.columnMapper = columnMapper;
	}

	@Override
	public void handleEvent(ColumnDeletedEvent e) {
		if (
				e.getSource() == CyCore.cy.getCurrentNetwork().getDefaultEdgeTable() ||
				e.getSource() == CyCore.cy.getCurrentNetwork().getDefaultNetworkTable() ||
				e.getSource() == CyCore.cy.getCurrentNetwork().getDefaultNodeTable()
				
			)
		{
			columnMapper.updateValues();
		}
	}

	@Override
	public void handleEvent(ColumnCreatedEvent e) {
		if (
				e.getSource() == CyCore.cy.getCurrentNetwork().getDefaultEdgeTable() ||
				e.getSource() == CyCore.cy.getCurrentNetwork().getDefaultNetworkTable() ||
				e.getSource() == CyCore.cy.getCurrentNetwork().getDefaultNodeTable()
				
			)
		{
			columnMapper.updateValues();
		}
	}

	@Override
	public void handleEvent(RemovedEdgesEvent e) {
		if (
				e.getSource() == CyCore.cy.getCurrentNetwork()
			)
		{
			columnMapper.updateValues();
		}
	}

	@Override
	public void handleEvent(AddedEdgesEvent e) {
		if (
				e.getSource() == CyCore.cy.getCurrentNetwork()
			)
		{
			columnMapper.updateValues();
		}
	}

	@Override
	public void handleEvent(SessionLoadedEvent e) {
		columnMapper.updateValues();
	}

	@Override
	public void handleEvent(SetCurrentNetworkEvent e) {
		columnMapper.updateValues();
	}

}
