package de.hhu.ba.yoshikoWrapper.swing;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import javax.swing.JOptionPane;

import org.slf4j.Logger;

import de.hhu.ba.yoshikoWrapper.core.CyCore;
import de.hhu.ba.yoshikoWrapper.core.GraphicsLoader;
import de.hhu.ba.yoshikoWrapper.core.Hint;
import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;
import de.hhu.ba.yoshikoWrapper.logging.YoshikoLogger;

/**
 * Bothers the user with useful hints
 *
 */
public class HintManager {
	
	private static Logger logger = YoshikoLogger.getInstance().getLogger();
	
	private static final Runnable useMappingHint = new Runnable() {

		@Override
		public void run() {
			JOptionPane.showMessageDialog(null, LocalizationManager.get("noMappingHint"), LocalizationManager.get("yoshikoHint"),JOptionPane.INFORMATION_MESSAGE);
		}

	};
	
	private static final Runnable firstStart = new Runnable() {

		@Override
		public void run() {
			 JOptionPane.showMessageDialog(null, LocalizationManager.get("firstStart"), "Yoshiko Welcome", JOptionPane.INFORMATION_MESSAGE, GraphicsLoader.getLogo(40));
		}

	};

	private final static Map<Hint,Runnable> hints;
	
	static {
		Map<Hint, Runnable> map = new HashMap<Hint,Runnable>();
		map.put(Hint.USE_MAPPING, useMappingHint);
		map.put(Hint.FIRST_START, firstStart);
		hints = Collections.unmodifiableMap(map);
	}

	public static void showMappingHint(Hint hint) {
		if (
				CyCore.getConfig(
						hint.toString()+"shown"
				) == null
			) 
		{
			
			//Save property so we dont show this again
			CyCore.cm.getProperties().setProperty(hint.toString()+ "shown", "1");
			if (hints.get(hint) != null) {
				hints.get(hint).run();
			}
			else {
				logger.warn("Asked for a hint that doesnt exist with hint name: "+hint.toString());
			}
			
		}
	}
	


}
